@@ -1,7 +1,8 @@
 """
 Contains many common functions
 """
-import os,time,re,datetime
+import os, time, re
+
 
 def truncate(string, chars_number):
     """
@@ -9,18 +10,21 @@ def truncate(string, chars_number):
     """
     return string[:chars_number] + '..' if len(string) > chars_number else string
 
+
 def datetimeToUnix(date):
     """
     Transform a datetime in unix format with milliseconds
     """
     return int(time.mktime(date.timetuple())*1000)
 
+
 def datetimeToUnixSec(date):
     """
     Transform a datetime in unix format
     """
     return int(time.mktime(date.timetuple()))
 
+
 def upy_re_match(regex,value):
     """
     Checks if value match with regex
@@ -28,6 +32,7 @@ def upy_re_match(regex,value):
     reg = re.compile(regex)
     return reg.match(value)  
 
+
 def compare_dicts(dict1, dict2):
     """
     Checks if dict1 equals dict2
@@ -37,6 +42,7 @@ def compare_dicts(dict1, dict2):
             return False
     return True
 
+
 def filter_files(path, string):
     """
     This function filter all files that contains the string passed as parameter in the name
@@ -46,7 +52,8 @@ def filter_files(path, string):
         return [f for f in listing if string in f]
     except:
         raise ValueError("Error in upy.contrib.tree.menu @ filter_files()")
-    
+
+
 def clean_cache(path, string_in_filename = None):
     """
     Cleans files contain string_in_filename from path 
@@ -58,6 +65,7 @@ def clean_cache(path, string_in_filename = None):
         for tmpfile in os.listdir(path):
             os.unlink("%s%s" % (path,tmpfile))
             
+
 def clean_path(source):
     """
     Replace backslashes from source.file_name with a slash 
@@ -65,6 +73,7 @@ def clean_path(source):
     source.file_name = source.file_name.replace('\\','/')
     return source
 
+
 def getAccentedVocal(vocal,acc_type="g"):
     """
     It returns given vocal with grave or acute accent 
@@ -76,8 +85,9 @@ def getAccentedVocal(vocal,acc_type="g"):
               'u':{'g':u'\xf9','a':u'\xfa'}}
     return vocals[vocal][acc_type]
 
+
 def _av(vocal,acc_type="g"):
     """
     It's a shortcut to getAccentedVocal function
     """
-    return getAccentedVocal(vocal,acc_type)
\ No newline at end of file
+    return getAccentedVocal(vocal,acc_type)
